'use strict';

exports.__esModule = true;
exports.createBowerPackage = undefined;

var _path = require('path');

var _fs = require('fs');

var _archiver = require('archiver');

var _archiver2 = _interopRequireDefault(_archiver);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var generateZip = function generateZip(packageDir, packageVersion, callback) {
  (0, _fs.readFile)((0, _path.join)(packageDir, 'bower.json'), 'utf8', function (error, bowerJSON) {
    if (error) {
      callback(error);
      return;
    }

    var bowerConfig = Object.assign(JSON.parse(bowerJSON), { version: packageVersion });
    var main = bowerConfig.main;
    var files = Array.isArray(main) ? main : [main];
    var bowerZip = (0, _path.join)(packageDir, 'bower.zip');
    var out = (0, _fs.createWriteStream)(bowerZip);

    var zip = (0, _archiver2.default)('zip', {});
    var callbackWasCalled = false;

    var onError = function onError(error) {
      if (callbackWasCalled) return;

      callbackWasCalled = true;
      callback(error);
    };

    var onFinish = function onFinish() {
      if (callbackWasCalled) return;

      callbackWasCalled = true;
      callback(null, bowerZip);
    };

    zip.on('error', onError);
    out.on('error', onError);
    out.on('finish', onFinish);

    zip.pipe(out);

    // add `bower.json` file with updated version
    zip.append(JSON.stringify(bowerConfig, null, 2), { name: 'bower.json' });

    // add all files from `main` section of Bower config
    files.forEach(function (file) {
      zip.file((0, _path.join)(packageDir, file), { name: file });
    });

    zip.finalize();
  });
};

var createBowerPackage = exports.createBowerPackage = function createBowerPackage(packageDir, callback) {
  (0, _fs.stat)((0, _path.join)(packageDir, 'bower.json'), function (error, stat) {
    if (error || !stat.isFile()) {
      callback(new Error('Missing bower.json'));
      return;
    }

    (0, _fs.readFile)((0, _path.join)(packageDir, 'package.json'), 'utf8', function (error, packageJSON) {
      if (error) {
        callback(error);
        return;
      }

      var packageVersion = JSON.parse(packageJSON).version;

      generateZip(packageDir, packageVersion, callback);
    });
  });
};